summaryrefslogtreecommitdiffstats
path: root/src/infodialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
commit4304e8d9dab8e20513e38e71b0debdf6937b630c (patch)
tree76a86f013a811449a5b5bfbbbb962e7db0bbcc6a /src/infodialog.h
parentba24506b3bb46312d998468ad3c1a7f28058b2bd (diff)
downloadtdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.tar.gz
tdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.zip
Finish TQt4 port of kpowersave
This enables both Qt3 and Qt4 builds git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpowersave@1228282 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/infodialog.h')
-rw-r--r--src/infodialog.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/infodialog.h b/src/infodialog.h
index 7d419dd..d24acb3 100644
--- a/src/infodialog.h
+++ b/src/infodialog.h
@@ -38,13 +38,14 @@
class infoDialog: public info_Dialog {
Q_OBJECT
+ TQ_OBJECT
public:
//! default constructor
- infoDialog( KConfig *config = 0, QString captionName = QString(), QString message = QString(),
- QString dontShowAgainMsg = QString(), QString settingsEntryName = QString(),
- QWidget *parent = 0, const char *name = 0);
+ infoDialog( KConfig *config = 0, TQString captionName = TQString(), TQString message = TQString(),
+ TQString dontShowAgainMsg = TQString(), TQString settingsEntryName = TQString(),
+ TQWidget *tqparent = 0, const char *name = 0);
//! default destructor
~infoDialog();
@@ -57,10 +58,10 @@ private:
KConfig *settings;
//! name of the entry in the settings
/*! QString store the name of the settings entry to
* store settings of 'DontShowAgain' checkbox
*/
- QString entryName;
+ TQString entryName;
//! represent if the dialog is disabled by user
/*!
@@ -57,10 +58,10 @@ private:
KConfig *settings;
//! name of the entry in the settings
- /*! QString store the name of the settings entry to
+ /*! TQString store the name of the settings entry to
* store settings of 'DontShowAgain' checkbox
*/